netapp_ontap.models.s3_bucket_lifecycle_object_filter API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_bucket_lifecycle_object_filter`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3BucketLifecycleObjectFilterSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3BucketLifecycleObjectFilter object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the s3_bucket_lifecycle_object_filter.

  `prefix: str GET POST`

    A prefix that is matched against object-names within a bucket.

    Example: /logs

  `size_greater_than: Size GET POST`

    Size of the object greater than specified for which the corresponding lifecycle rule is to be applied.

    Example: 10240

  `size_less_than: Size GET POST`

    Size of the object smaller than specified for which the corresponding lifecycle rule is to be applied.

    Example: 10485760

  `tags: List[str] GET POST`

    An array of key-value paired tags of the form or .

    Example: ["project1=projA","project2=projB"]